@@ -1,7 +1,7 @@
 var a = "FAIL";
 try {
     throw 1;
-} catch (args) {
+} catch (args__2) {
     var a = "PASS";
 }
 console.log(a);
