@@ -1,7 +1,7 @@
 var a = "PASS";
 try {
     throw "FAIL1";
-} catch (a1) {
-    var a1 = "FAIL2";
+} catch (a__2) {
+    var a__2 = "FAIL2";
 }
 console.log(a);
